@@ -5,16 +5,16 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.104 ;
+use IO::Compress::Base 2.205 ;
 
-use IO::Compress::Base::Common  2.104 qw();
-use IO::Compress::Adapter::Bzip2 2.104 ;
+use IO::Compress::Base::Common  2.205 qw();
+use IO::Compress::Adapter::Bzip2 2.205 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bzip2Error);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $Bzip2Error = '';
 
 @ISA    = qw(IO::Compress::Base Exporter);
@@ -51,7 +51,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.104 qw(:Parse);
+    use IO::Compress::Base::Common  2.205 qw(:Parse);
 
     return (
             'blocksize100k' => [IO::Compress::Base::Common::Parse_unsigned,  1],
@@ -387,7 +387,7 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
+=head2 Oneshot Examples
 
 Here are a few example that show the capabilities of the module.
 
@@ -466,7 +466,10 @@ The format of the constructor for C<IO::Compress::Bzip2> is shown below
     my $z = IO::Compress::Bzip2->new( $output [,OPTS] )
         or die "IO::Compress::Bzip2 failed: $Bzip2Error\n";
 
-It returns an C<IO::Compress::Bzip2> object on success and undef on failure.
+The constructor takes one mandatory parameter, C<$output>, defined below and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
+It returns an C<IO::Compress::Bzip2> object on success and C<undef> on failure.
 The variable C<$Bzip2Error> will contain an error message on failure.
 
 If you are running Perl 5.005 or better the object, C<$z>, returned from
@@ -479,6 +482,18 @@ these forms
     $z->print("hello world\n");
     print $z "hello world\n";
 
+Below is a simple exaple of using the OO interface to create an output file
+C<myfile.bz2> and write some data to it.
+
+    my $filename = "myfile.bz2";
+    my $z = IO::Compress::Bzip2->new($filename)
+        or die "IO::Compress::Bzip2 failed: $Bzip2Error\n";
+
+    $z->print("abcde");
+    $z->close();
+
+See the L</Examples> for more.
+
 The mandatory parameter C<$output> is used to control the destination
 of the compressed data. This parameter can take one of these forms.
 
@@ -576,7 +591,52 @@ This is a placeholder option.
 
 =head2 Examples
 
-TODO
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities
+of the module. The code reads data from STDIN or all the files given on the
+commandline, compresses it, and writes the compressed data to STDOUT.
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Bzip2 qw(bzip2 $Bzip2Error) ;
+
+    my $z = IO::Compress::Bzip2->new("-", Stream => 1)
+        or die "IO::Compress::Bzip2 failed: $Bzip2Error\n";
+
+    while (<>) {
+        $z->print("abcde");
+    }
+    $z->close();
+
+Note the use of C<"-"> to means C<STDOUT>. Alternatively you can use C<\*STDOUT>.
+
+=head3 Compressing a file from the filesystem
+
+To read the contents of the file C<file1.txt> and write the compressed
+data to the file C<file1.txt.bz2> there are a few options
+
+Start by creating the compression object and opening the input file
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Bzip2 qw(bzip2 $Bzip2Error) ;
+
+    my $input = "file1.txt";
+    my $z = IO::Compress::Bzip2->new("file1.txt.bz2")
+        or die "IO::Compress::Bzip2 failed: $Bzip2Error\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # not forgetting to close the compressed file
+    $z->close();
 
 =head1 Methods
 
@@ -818,7 +878,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
