@@ -8,16 +8,16 @@ use bytes;
 
 require Exporter ;
 
-use IO::Compress::RawDeflate 2.104 ();
-use IO::Compress::Adapter::Deflate 2.104 ;
+use IO::Compress::RawDeflate 2.205 ();
+use IO::Compress::Adapter::Deflate 2.205 ;
 
-use IO::Compress::Zlib::Constants 2.104 ;
-use IO::Compress::Base::Common  2.104 qw();
+use IO::Compress::Zlib::Constants 2.205 ;
+use IO::Compress::Base::Common  2.205 qw();
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $DeflateError);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $DeflateError = '';
 
 @ISA    = qw(IO::Compress::RawDeflate Exporter);
@@ -42,92 +42,35 @@ sub deflate
     return $obj->_def(@_);
 }
 
-
-sub bitmask($$$$)
+sub mkComp
 {
-    my $into  = shift ;
-    my $value  = shift ;
-    my $offset = shift ;
-    my $mask   = shift ;
+    my $self = shift ;
+    my $got = shift ;
 
-    return $into | (($value & $mask) << $offset ) ;
+    my ($obj, $errstr, $errno) = IO::Compress::Adapter::Deflate::mkCompObject1(
+                                                 $got->getValue('crc32'),
+                                                 $got->getValue('adler32'),
+                                                 $got->getValue('level'),
+                                                 $got->getValue('strategy')
+                                                 );
+
+   return $self->saveErrorString(undef, $errstr, $errno)
+       if ! defined $obj;
+
+   return $obj;
 }
 
-sub mkDeflateHdr($$$;$)
-{
-    my $method = shift ;
-    my $cinfo  = shift;
-    my $level  = shift;
-    my $fdict_adler = shift  ;
-
-    my $cmf = 0;
-    my $flg = 0;
-    my $fdict = 0;
-    $fdict = 1 if defined $fdict_adler;
-
-    $cmf = bitmask($cmf, $method, ZLIB_CMF_CM_OFFSET,    ZLIB_CMF_CM_BITS);
-    $cmf = bitmask($cmf, $cinfo,  ZLIB_CMF_CINFO_OFFSET, ZLIB_CMF_CINFO_BITS);
-
-    $flg = bitmask($flg, $fdict,  ZLIB_FLG_FDICT_OFFSET, ZLIB_FLG_FDICT_BITS);
-    $flg = bitmask($flg, $level,  ZLIB_FLG_LEVEL_OFFSET, ZLIB_FLG_LEVEL_BITS);
-
-    my $fcheck = 31 - ($cmf * 256 + $flg) % 31 ;
-    $flg = bitmask($flg, $fcheck, ZLIB_FLG_FCHECK_OFFSET, ZLIB_FLG_FCHECK_BITS);
-
-    my $hdr =  pack("CC", $cmf, $flg) ;
-    $hdr .= pack("N", $fdict_adler) if $fdict ;
-
-    return $hdr;
-}
 
 sub mkHeader
 {
     my $self = shift ;
-    my $param = shift ;
-
-    my $level = $param->getValue('level');
-    my $strategy = $param->getValue('strategy');
-
-    my $lflag ;
-    $level = 6
-        if $level == Z_DEFAULT_COMPRESSION ;
-
-    if (ZLIB_VERNUM >= 0x1210)
-    {
-        if ($strategy >= Z_HUFFMAN_ONLY || $level < 2)
-         {  $lflag = ZLIB_FLG_LEVEL_FASTEST }
-        elsif ($level < 6)
-         {  $lflag = ZLIB_FLG_LEVEL_FAST }
-        elsif ($level == 6)
-         {  $lflag = ZLIB_FLG_LEVEL_DEFAULT }
-        else
-         {  $lflag = ZLIB_FLG_LEVEL_SLOWEST }
-    }
-    else
-    {
-        $lflag = ($level - 1) >> 1 ;
-        $lflag = 3 if $lflag > 3 ;
-    }
-
-     #my $wbits = (MAX_WBITS - 8) << 4 ;
-    my $wbits = 7;
-    mkDeflateHdr(ZLIB_CMF_CM_DEFLATED, $wbits, $lflag);
+    return '';
 }
 
-sub ckParams
-{
-    my $self = shift ;
-    my $got = shift;
-
-    $got->setValue('adler32' => 1);
-    return 1 ;
-}
-
-
 sub mkTrailer
 {
     my $self = shift ;
-    return pack("N", *$self->{Compress}->adler32()) ;
+    return '';
 }
 
 sub mkFinalTrailer
@@ -135,12 +78,6 @@ sub mkFinalTrailer
     return '';
 }
 
-#sub newHeader
-#{
-#    my $self = shift ;
-#    return *$self->{Header};
-#}
-
 sub getExtraParams
 {
     my $self = shift ;
@@ -417,7 +354,7 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
+=head2 Oneshot Examples
 
 Here are a few example that show the capabilities of the module.
 
@@ -496,7 +433,10 @@ The format of the constructor for C<IO::Compress::Deflate> is shown below
     my $z = IO::Compress::Deflate->new( $output [,OPTS] )
         or die "IO::Compress::Deflate failed: $DeflateError\n";
 
-It returns an C<IO::Compress::Deflate> object on success and undef on failure.
+The constructor takes one mandatory parameter, C<$output>, defined below and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
+It returns an C<IO::Compress::Deflate> object on success and C<undef> on failure.
 The variable C<$DeflateError> will contain an error message on failure.
 
 If you are running Perl 5.005 or better the object, C<$z>, returned from
@@ -509,6 +449,18 @@ these forms
     $z->print("hello world\n");
     print $z "hello world\n";
 
+Below is a simple exaple of using the OO interface to create an output file
+C<myfile.1950> and write some data to it.
+
+    my $filename = "myfile.1950";
+    my $z = IO::Compress::Deflate->new($filename)
+        or die "IO::Compress::Deflate failed: $DeflateError\n";
+
+    $z->print("abcde");
+    $z->close();
+
+See the L</Examples> for more.
+
 The mandatory parameter C<$output> is used to control the destination
 of the compressed data. This parameter can take one of these forms.
 
@@ -648,7 +600,52 @@ This is a placeholder option.
 
 =head2 Examples
 
-TODO
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities
+of the module. The code reads data from STDIN or all the files given on the
+commandline, compresses it, and writes the compressed data to STDOUT.
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Deflate qw(deflate $DeflateError) ;
+
+    my $z = IO::Compress::Deflate->new("-", Stream => 1)
+        or die "IO::Compress::Deflate failed: $DeflateError\n";
+
+    while (<>) {
+        $z->print("abcde");
+    }
+    $z->close();
+
+Note the use of C<"-"> to means C<STDOUT>. Alternatively you can use C<\*STDOUT>.
+
+=head3 Compressing a file from the filesystem
+
+To read the contents of the file C<file1.txt> and write the compressed
+data to the file C<file1.txt.1950> there are a few options
+
+Start by creating the compression object and opening the input file
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Deflate qw(deflate $DeflateError) ;
+
+    my $input = "file1.txt";
+    my $z = IO::Compress::Deflate->new("file1.txt.1950")
+        or die "IO::Compress::Deflate failed: $DeflateError\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # not forgetting to close the compressed file
+    $z->close();
 
 =head1 Methods
 
@@ -940,6 +937,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -952,7 +952,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
