@@ -4,41 +4,41 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.104 qw(:Status );
-use IO::Compress::RawDeflate 2.104 ();
-use IO::Compress::Adapter::Deflate 2.104 ;
-use IO::Compress::Adapter::Identity 2.104 ;
-use IO::Compress::Zlib::Extra 2.104 ;
-use IO::Compress::Zip::Constants 2.104 ;
+use IO::Compress::Base::Common  2.205 qw(:Status );
+use IO::Compress::RawDeflate 2.205 ();
+use IO::Compress::Adapter::Deflate 2.205 ;
+use IO::Compress::Adapter::Identity 2.205 ;
+use IO::Compress::Zlib::Extra 2.205 ;
+use IO::Compress::Zip::Constants 2.205 ;
 
 use File::Spec();
 use Config;
 
-use Compress::Raw::Zlib  2.103 ();
+use Compress::Raw::Zlib  2.205 ();
 
 BEGIN
 {
     eval { require IO::Compress::Adapter::Bzip2 ;
-           IO::Compress::Adapter::Bzip2->import( 2.103 );
+           IO::Compress::Adapter::Bzip2->import( 2.205 );
            require IO::Compress::Bzip2 ;
-           IO::Compress::Bzip2->import( 2.103 );
+           IO::Compress::Bzip2->import( 2.205 );
          } ;
 
     eval { require IO::Compress::Adapter::Lzma ;
-           IO::Compress::Adapter::Lzma->import( 2.103 );
+           IO::Compress::Adapter::Lzma->import( 2.205 );
            require IO::Compress::Lzma ;
-           IO::Compress::Lzma->import( 2.103 );
+           IO::Compress::Lzma->import( 2.205 );
          } ;
 
     eval { require IO::Compress::Adapter::Xz ;
-           IO::Compress::Adapter::Xz->import( 2.103 );
+           IO::Compress::Adapter::Xz->import( 2.205 );
            require IO::Compress::Xz ;
-           IO::Compress::Xz->import( 2.103 );
+           IO::Compress::Xz->import( 2.205 );
          } ;
     eval { require IO::Compress::Adapter::Zstd ;
-           IO::Compress::Adapter::Zstd->import( 2.103 );
+           IO::Compress::Adapter::Zstd->import( 2.205 );
            require IO::Compress::Zstd ;
-           IO::Compress::Zstd->import( 2.103 );
+           IO::Compress::Zstd->import( 2.205 );
          } ;
 }
 
@@ -47,7 +47,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $ZipError);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $ZipError = '';
 
 @ISA = qw(IO::Compress::RawDeflate Exporter);
@@ -85,20 +85,24 @@ sub isMethodAvailable
         if $method == ZIP_CM_STORE || $method == ZIP_CM_DEFLATE ;
 
     return 1
-        if $method == ZIP_CM_BZIP2 and
-           defined $IO::Compress::Adapter::Bzip2::VERSION;
+        if $method == ZIP_CM_BZIP2 &&
+           defined $IO::Compress::Adapter::Bzip2::VERSION &&
+           defined &{ "IO::Compress::Adapter::Bzip2::mkRawZipCompObject" };
 
     return 1
-        if $method == ZIP_CM_LZMA and
-           defined $IO::Compress::Adapter::Lzma::VERSION;
+        if $method == ZIP_CM_LZMA &&
+           defined $IO::Compress::Adapter::Lzma::VERSION &&
+           defined &{ "IO::Compress::Adapter::Lzma::mkRawZipCompObject" };
 
     return 1
-        if $method == ZIP_CM_XZ and
-           defined $IO::Compress::Adapter::Xz::VERSION;
+        if $method == ZIP_CM_XZ &&
+           defined $IO::Compress::Adapter::Xz::VERSION &&
+           defined &{ "IO::Compress::Adapter::Xz::mkRawZipCompObject" };
 
     return 1
-        if $method == ZIP_CM_ZSTD and
-           defined $IO::Compress::Adapter::ZSTD::VERSION;
+        if $method == ZIP_CM_ZSTD &&
+           defined $IO::Compress::Adapter::ZSTD::VERSION &&
+           defined &{ "IO::Compress::Adapter::ZSTD::mkRawZipCompObject" };
 
     return 0;
 }
@@ -566,6 +570,8 @@ sub mkFinalTrailer
         $z64e .= U64::pack_V64 $entries   ; # entries in central dir
         $z64e .= U64::pack_V64 $cd_len    ; # size of central dir
         $z64e .= *$self->{ZipData}{Offset}->getPacked_V64() ; # offset to start central dir
+        $z64e .= *$self->{ZipData}{extrafieldzip64}  # otional extra field
+            if defined *$self->{ZipData}{extrafieldzip64} ;
 
         $z64e  = pack("V", ZIP64_END_CENTRAL_REC_HDR_SIG) # signature
               .  U64::pack_V64(length $z64e)
@@ -638,7 +644,7 @@ sub ckParams
     }
 
     *$self->{ZipData}{AnyZip64} = 1
-        if $got->getValue('zip64');
+        if $got->getValue('zip64') || $got->getValue('extrafieldzip64') ;
     *$self->{ZipData}{Zip64} = $got->getValue('zip64');
     *$self->{ZipData}{Stream} = $got->getValue('stream');
 
@@ -658,7 +664,7 @@ sub ckParams
 
     *$self->{ZipData}{ZipComment} = $got->getValue('zipcomment') ;
 
-    for my $name (qw( extrafieldlocal extrafieldcentral ))
+    for my $name (qw( extrafieldlocal extrafieldcentral extrafieldzip64))
     {
         my $data = $got->getValue($name) ;
         if (defined $data) {
@@ -667,6 +673,7 @@ sub ckParams
                 if $bad ;
 
             $got->setValue($name, $data) ;
+            *$self->{ZipData}{$name} = $data;
         }
     }
 
@@ -731,6 +738,7 @@ our %PARAMS = (
             'textflag'  => [IO::Compress::Base::Common::Parse_boolean,   0],
             'extrafieldlocal'  => [IO::Compress::Base::Common::Parse_any,    undef],
             'extrafieldcentral'=> [IO::Compress::Base::Common::Parse_any,    undef],
+            'extrafieldzip64'  => [IO::Compress::Base::Common::Parse_any,    undef],
 
             # Lzma
             'preset'   => [IO::Compress::Base::Common::Parse_unsigned, 6],
@@ -1053,12 +1061,24 @@ See L<File::GlobMapper|File::GlobMapper> for more details.
 If the C<$input_filename_or_reference> parameter is any other type,
 C<undef> will be returned.
 
-In addition, if C<$input_filename_or_reference> is a simple filename,
-the default values for
-the C<Name>, C<Time>, C<TextFlag>, C<ExtAttr>, C<exUnixN> and C<exTime> options will be sourced from that file.
+In addition, if C<$input_filename_or_reference> corresponds to a filename
+from the filesystem, a number of zip file header fields will be populated by default
+using the following attributes from the input file
+
+=over 5
+
+=item * the full filename contained in C<$input_filename_or_reference>
+
+=item * the file protection attributes
+
+=item * the UID/GID for the file
+
+=item * the file timestamps
+
+=back
 
 If you do not want to use these defaults they can be overridden by
-explicitly setting the C<Name>, C<Time>, C<TextFlag>, C<ExtAttr>, C<exUnixN> and C<exTime> options or by setting the
+explicitly setting one, or more, of the C<Name>, C<Time>, C<TextFlag>, C<ExtAttr>, C<exUnixN> and C<exTime> options or by setting the
 C<Minimal> parameter.
 
 =head3 The C<$output_filename_or_reference> parameter
@@ -1186,7 +1206,7 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
+=head2 Oneshot Examples
 
 Here are a few example that show the capabilities of the module.
 
@@ -1297,7 +1317,10 @@ The format of the constructor for C<IO::Compress::Zip> is shown below
     my $z = IO::Compress::Zip->new( $output [,OPTS] )
         or die "IO::Compress::Zip failed: $ZipError\n";
 
-It returns an C<IO::Compress::Zip> object on success and undef on failure.
+The constructor takes one mandatory parameter, C<$output>, defined below and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
+It returns an C<IO::Compress::Zip> object on success and C<undef> on failure.
 The variable C<$ZipError> will contain an error message on failure.
 
 If you are running Perl 5.005 or better the object, C<$z>, returned from
@@ -1310,6 +1333,18 @@ these forms
     $z->print("hello world\n");
     print $z "hello world\n";
 
+Below is a simple exaple of using the OO interface to create an output file
+C<myfile.zip> and write some data to it.
+
+    my $filename = "myfile.zip";
+    my $z = IO::Compress::Zip->new($filename)
+        or die "IO::Compress::Zip failed: $ZipError\n";
+
+    $z->print("abcde");
+    $z->close();
+
+See the L</Examples> for more.
+
 The mandatory parameter C<$output> is used to control the destination
 of the compressed data. This parameter can take one of these forms.
 
@@ -1830,7 +1865,111 @@ This is a placeholder option.
 
 =head2 Examples
 
-TODO
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities
+of the module. The code reads data from STDIN or all the files given on the
+commandline, compresses it, and writes the compressed data to STDOUT.
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Zip qw(zip $ZipError) ;
+
+    my $z = IO::Compress::Zip->new("-", Stream => 1)
+        or die "IO::Compress::Zip failed: $ZipError\n";
+
+    while (<>) {
+        $z->print("abcde");
+    }
+    $z->close();
+
+Note the use of C<"-"> to means C<STDOUT>. Alternatively you can use C<\*STDOUT>.
+
+One problem with creating a zip archive directly from STDIN can be demonstrated by looking at
+the contents of the zip file, output.zip, that we have just created
+(assumg you have redirected it to a file called C<output.zip>).
+
+    $ unzip -l output.zip
+    Archive:  output.zip
+    Length      Date    Time    Name
+    ---------  ---------- -----   ----
+        12  2019-08-16 22:21
+    ---------                     -------
+        12                     1 file
+
+The archive member (filename) used is the empty string.
+
+If that doesn't suit your needs, you can explicitly set the filename used
+in the zip archive by specifying the L<Name|"File Naming Options"> option, like so
+
+    my $z = IO::Compress::Zip->new("-", Name => "hello.txt", Stream => 1)
+
+Now the contents of the zip file looks like this
+
+    $ unzip -l output.zip
+    Archive:  output.zip
+    Length      Date    Time    Name
+    ---------  ---------- -----   ----
+        12  2019-08-16 22:22   hello.txt
+    ---------                     -------
+        12                     1 file
+
+=head3 Compressing a file from the filesystem
+
+To read the contents of the file C<file1.txt> and write the compressed
+data to the file C<file1.txt.zip> there are a few options
+
+Start by creating the compression object and opening the input file
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Zip qw(zip $ZipError) ;
+
+    my $input = "file1.txt";
+    my $z = IO::Compress::Zip->new("file1.txt.zip")
+        or die "IO::Compress::Zip failed: $ZipError\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # not forgetting to close the compressed file
+    $z->close();
+
+=head3 Compressing multiple files
+
+To create a zip file, C<output.zip>, that contains the compressed contents
+of the files C<alpha.txt> and C<beta.txt>
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Zip qw(zip $ZipError) ;
+
+    my $z = IO::Compress::Zip->new("output.zip", Name => "alpha.txt")
+        or die "IO::Compress::Zip failed: $ZipError\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # move to next file
+    $z->newStream(Name => "beta.txt")
+
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    $z->close();
 
 =head1 Methods
 
@@ -2131,6 +2270,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -2143,7 +2285,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
