@@ -6,22 +6,22 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.104 qw(:Parse);
+use IO::Compress::Base::Common  2.205 qw(:Parse);
 
-use IO::Uncompress::Adapter::Inflate  2.104 ();
+use IO::Uncompress::Adapter::Inflate  2.205 ();
 
 
-use IO::Uncompress::Base  2.104 ;
-use IO::Uncompress::Gunzip  2.104 ;
-use IO::Uncompress::Inflate  2.104 ;
-use IO::Uncompress::RawInflate  2.104 ;
-use IO::Uncompress::Unzip  2.104 ;
+use IO::Uncompress::Base  2.205 ;
+use IO::Uncompress::Gunzip  2.205 ;
+use IO::Uncompress::Inflate  2.205 ;
+use IO::Uncompress::RawInflate  2.205 ;
+use IO::Uncompress::Unzip  2.205 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $AnyInflateError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -421,7 +421,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.Compressed> and write the
 uncompressed data to the file C<file1.txt>.
@@ -481,6 +481,9 @@ The format of the constructor for IO::Uncompress::AnyInflate is shown below
     my $z = IO::Uncompress::AnyInflate->new( $input [OPTS] )
         or die "IO::Uncompress::AnyInflate failed: $AnyInflateError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::AnyInflate> object on success and undef on failure.
 The variable C<$AnyInflateError> will contain an error message on failure.
 
@@ -493,6 +496,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.Compressed> and write its contents to stdout.
+
+    my $filename = "myfile.Compressed";
+    my $z = IO::Uncompress::AnyInflate->new($filename)
+        or die "IO::Uncompress::AnyInflate failed: $AnyInflateError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -689,10 +706,6 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -986,6 +999,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -998,7 +1014,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
