@@ -5,15 +5,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.104 qw(:Status );
-use IO::Compress::Zlib::Constants 2.104 ;
+use IO::Compress::Base::Common  2.205 qw(:Status );
+use IO::Compress::Zlib::Constants 2.205 ;
 
-use IO::Uncompress::RawInflate  2.104 ;
+use IO::Uncompress::RawInflate  2.205 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $InflateError);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $InflateError = '';
 
 @ISA    = qw(IO::Uncompress::RawInflate Exporter);
@@ -479,7 +479,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.1950> and write the
 uncompressed data to the file C<file1.txt>.
@@ -539,6 +539,9 @@ The format of the constructor for IO::Uncompress::Inflate is shown below
     my $z = IO::Uncompress::Inflate->new( $input [OPTS] )
         or die "IO::Uncompress::Inflate failed: $InflateError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::Inflate> object on success and undef on failure.
 The variable C<$InflateError> will contain an error message on failure.
 
@@ -551,6 +554,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.1950> and write its contents to stdout.
+
+    my $filename = "myfile.1950";
+    my $z = IO::Uncompress::Inflate->new($filename)
+        or die "IO::Uncompress::Inflate failed: $InflateError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -685,10 +702,6 @@ uncompressed data actually contained in the file.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -982,6 +995,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -994,7 +1010,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
