@@ -5,16 +5,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use Compress::Raw::Zlib  2.103 ;
-use IO::Compress::Base::Common  2.104 qw(:Status );
+use Compress::Raw::Zlib  2.205 ;
+use IO::Compress::Base::Common  2.205 qw(:Status );
 
-use IO::Uncompress::Base  2.104 ;
-use IO::Uncompress::Adapter::Inflate  2.104 ;
+use IO::Uncompress::Base  2.205 ;
+use IO::Uncompress::Adapter::Inflate  2.205 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $RawInflateError);
 
-$VERSION = '2.104';
+$VERSION = '2.205';
 $RawInflateError = '';
 
 @ISA    = qw(IO::Uncompress::Base Exporter);
@@ -624,7 +624,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.1951> and write the
 uncompressed data to the file C<file1.txt>.
@@ -684,6 +684,9 @@ The format of the constructor for IO::Uncompress::RawInflate is shown below
     my $z = IO::Uncompress::RawInflate->new( $input [OPTS] )
         or die "IO::Uncompress::RawInflate failed: $RawInflateError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::RawInflate> object on success and undef on failure.
 The variable C<$RawInflateError> will contain an error message on failure.
 
@@ -696,6 +699,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.1951> and write its contents to stdout.
+
+    my $filename = "myfile.1951";
+    my $z = IO::Uncompress::RawInflate->new($filename)
+        or die "IO::Uncompress::RawInflate failed: $RawInflateError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -813,10 +830,6 @@ This option is a no-op.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -1110,6 +1123,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -1122,7 +1138,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
